Summary: Open PBS batch system RPM with many useful fixes.
Name: pbs
Version: 2.3.12
Release: 23
URL: http://www.openpbs.org
License: See /usr/share/doc/%{name}-%{version}-%{release}/PBS_License.txt
Group: OSC

BuildRoot: %{_tmppath}/%{name}-root

Source0: %{name}-%{version}.tar.gz
Source1: pbs_server
Source2: pbs_sched
Source3: pbs_mom
Source4: pbs-server.pam
Patch1: mpiexec.patch
Patch2: fault-tolerance.patch
Patch3: prologue-environment.patch
Patch4: increase-timeouts-2.patch
Patch5: meminfo-2.patch
Patch6: no-munge-server-name.patch
Patch7: docfix.patch
Patch8: config-ia64.patch
Patch9: doc-cleanup.patch
Patch10: no-linux-headers.patch
Patch11: tracejob-line-size.patch
Patch12: server-node-list-length.patch
Patch13: compile-warning-fixes.patch
Patch14: mom-file-descriptor-leak.patch
Patch15: unused-tcp-interrupt.patch
Patch16: prologue-bounce.patch
Patch17: quickshutsig.patch
Patch18: node-alloc-bug.patch
Patch19: qterm.patch
Patch20: qmgr-readline.patch
Patch21: job-name-no-limit.patch
Patch22: mom-mlockall.patch
Patch23: install-verbose.patch
Patch24: compile-warning-fixes-2.patch
Patch25: shell-use-argv.patch
Patch26: maui-silver-rm-extension.patch
Patch27: compile-warning-fixes-3.patch
Patch28: mom-restart.patch
Patch29: rpm.patch
Patch30: vmem-accounting.patch
Patch31: libpbs-path.patch
Patch32: server-fd-close.patch
Patch33: neednodes-dynamic.patch
Patch34: errno-fix.patch
Patch35: gcc32-fix-2.patch
Patch36: more-server-sockets.patch
Patch37: interactive-with-script.patch
Patch38: pam_ruserok.patch
Patch39: less-ping-nodes.patch

AutoReqProv: no
Requires: tcl, tk

###################
##  DESCRIPTION  ##
###################

%description

This an rpm for the Portable Batch System, PBS. This package is built
from the Open-PBS-2.3.12 sources but includes several patches that
have proved useful in the reliability and usability of the batch
system. The patches include the following,

 - Support for mpiexec (http://www.osc.edu/~pw/mpiexec.html)
 - Proper host memory size calculation for Linux.
 - Support for Linux-2.4 series kernels, remove kernel header include.
 - Support for IA-64 Linux systems.
 - Install script and Makefile cleanups to support RPM.
 - Additional environment variables for more useful prologue, epilogue
   scripts.
 - Modified Cplant patch.

This package will install PBS_SERVER_HOME in /var/spool/pbs by
default. If this location is being used, it will not overwrite
anything in that directory (hopefully). The binaries will be installed
in /usr/local/%{name}-%{version}-%{release}. This makes the assumption
that all the compute nodes in the cluster will have access to that
directory through NFS or some other shared filesystem.

This rpm does not support the --prefix option for installation. There
are too many internal dependencies on the path being set at compile
time for security considerations. This rpm also strives to be very
explicit about the file permissions that are required for proper
operation of the batch system, so it is not possible to build the rpm
as a non-root user.


%package core
Summary: Core files needed for PBS operation
Group: OSC
%description core
This package contains the basic directory structure and files needed for PBS operation, as 
well as libraries and header files for the PBS API.


%package server
Summary: PBS server
Group: OSC
Requires: pbs-core, chkconfig
%description server
This package contains the binaries and configuration files needed to run the PBS server.


%package sched
Summary: PBS Scheduler
Group: OSC
Requires: pbs-core, chkconfig
%description sched
This package contains the default schedulers that come with PBS.


%package mom
Summary: PBS MOM daemon
Group: OSC
Requires: pbs-core, chkconfig
%description mom
This package contains the binaries and config files needed to run the PBS MOM daemon.


%package commands
Summary: PBS user commands
Group: OSC
Requires: tcl, tk, pbs-core
%description commands
This package contains the user commands needed to interact with the PBS server.


############
##  PREP  ##
############

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1
%patch28 -p1
%patch29 -p1
%patch30 -p1
%patch31 -p1
%patch32 -p1
%patch33 -p1
%patch34 -p1
%patch35 -p1
%patch36 -p1
%patch37 -p1
%patch38 -p1
%patch39 -p1

#############
##  BUILD  ##
#############

%build

CFLAGS='-DNO_SECURITY_CHECK' \
./configure --prefix=/usr/local/%{name}-%{version}-%{release} \
            --enable-docs \
            --enable-gui \
            --set-server-home=/var/spool/pbs \
            --set-default-server=localhost.localdomain \
            --disable-shell-pipe \
            --enable-shell-use-argv
make

# Create module file
cat > pbs-modfile <<EOF
#%Module########################################################################
##
## pbs modulefile
##
## This modulefile will add the /usr/local/%{name}-%{version}-%{release} filesystem
## to several environment variables.
##
# note that this is read by a Tcl interpretor
#
proc ModulesHelp { } {
        global pbsinst version

        puts stderr "\tpbs - loads the OpenPBS batch environment\n"
        puts stderr "\tThis adds \$pbsinst/* to several of the"
        puts stderr "\tenvironment variables."
        puts stderr "\n\tVersion \$version\n"
}

module-whatis	"loads the OpenPBS batch environment"

# for Tcl script use only
set version %{version}-%{release}
set pbsinst /usr/local/pbs-\$version

setenv          PBS_HOME	/var/spool/pbs
setenv		PBS_INSTALL	\$pbsinst
prepend-path    PATH   		\$pbsinst/bin
prepend-path    MANPATH		\$pbsinst/man

EOF


###############
##  INSTALL  ##
###############

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p -m755 $RPM_BUILD_ROOT
make install ROOT=$RPM_BUILD_ROOT

# Install init scripts
install -d $RPM_BUILD_ROOT/etc/rc.d/init.d
install -m 755 $RPM_SOURCE_DIR/pbs_server $RPM_BUILD_ROOT/etc/rc.d/init.d
install -m 755 $RPM_SOURCE_DIR/pbs_sched $RPM_BUILD_ROOT/etc/rc.d/init.d
install -m 755 $RPM_SOURCE_DIR/pbs_mom $RPM_BUILD_ROOT/etc/rc.d/init.d

# Install pbs pam file
install -d $RPM_BUILD_ROOT/etc/pam.d
install -m 644 $RPM_SOURCE_DIR/pbs-server.pam $RPM_BUILD_ROOT/etc/pam.d/pbs-server

# Install modulefile
install -d $RPM_BUILD_ROOT/usr/share/modulefiles
install -m 644 pbs-modfile $RPM_BUILD_ROOT/usr/share/modulefiles/%{name}-%{version}-%{release}
install -d $RPM_BUILD_ROOT/usr/local/share/modulefiles
install -m 644 pbs-modfile $RPM_BUILD_ROOT/usr/local/share/modulefiles/%{name}-%{version}-%{release}

# Install license file
install -d -m 755 $RPM_BUILD_ROOT/usr/share/doc/%{name}-%{version}-%{release}
install -m 644 PBS_License.txt $RPM_BUILD_ROOT/usr/share/doc/%{name}-%{version}-%{release}

# Make sure that server_priv/jobs directory exists
install -d -m 750 $RPM_BUILD_ROOT/var/spool/pbs/server_priv/jobs

# We don't want build host to be default server name
echo -e "# PBS server name goes here.  Remove this comment.\n" > $RPM_BUILD_ROOT/var/spool/pbs/server_name


###################
##  PRE-INSTALL  ##
###################

%pre core

# Be overly cautious
# Save PBS directory instead of overwriting
if [ -e /usr/local/%{name}-%{version}-%{release} ]; then
	mv /usr/local/%{name}-%{version}-%{release} /usr/local/%{name}-%{version}-%{release}.rpmsave
fi
# Save pbs link if it wasn't from an RPM installation
if [[ (-e /usr/local/%{name} || -h /usr/local/%{name}) && $1 = 1 ]]; then
	mv /usr/local/%{name} /usr/local/%{name}.rpmsave
fi


####################
##  POST-INSTALL  ##
####################

%post core

if [ -e /usr/local/%{name} ]; then
	if [ $1 > 1 ]; then
		cd /usr/local
		rm -f %{name}
		ln -s %{name}-%{version}-%{release} %{name}
	else
		echo "WARNING: /usr/local/%{name} exists.  Link will not be created."
		echo "WARNING: Make sure /usr/local/%{name} is a link to the current version."
		echo "         Otherwise, some programs may not work properly."
	fi
else
	cd /usr/local
	ln -s %{name}-%{version}-%{release} pbs
fi

cd /usr/share/modulefiles
ln -sf %{name}-%{version}-%{release} %{name}
cd /usr/local/share/modulefiles
ln -sf %{name}-%{version}-%{release} %{name}


%post server
# Make name of installation host the default server name, but don't
# add it again if this is an upgrade
if [ $1 = 1 ]; then
	uname -n > /var/spool/pbs/server_name
	/sbin/chkconfig --add pbs_server
	/sbin/chkconfig --level 2345 pbs_server off
fi


%post mom
if [ $1 = 1 ]; then
	/sbin/chkconfig --add pbs_mom
	/sbin/chkconfig --level 2345 pbs_mom off
fi


%post sched
if [ $1 = 1 ]; then
	/sbin/chkconfig --add pbs_sched
	/sbin/chkconfig --level 2345 pbs_sched off
fi


%post commands

# Make sure proper hostname is added to xpbsrc and xpbsmonrc
HNAME=`uname -n`
cd /usr/local/%{name}-%{version}-%{release}/lib/xpbs
if [ -e xpbsrc ]; then
	mv xpbsrc xpbsrc.src
	sed -e "s/localhost.localdomain/$HNAME/" xpbsrc.src > xpbsrc
	rm -f xpbsrc.src
else
	echo "WARNING: /usr/local/%{name}-%{version}-%{release}/lib/xpbs/xpbsrc does not exist."
fi

cd /usr/local/%{name}-%{version}-%{release}/lib/xpbsmon
if [ -e xpbsmonrc ]; then
        mv xpbsmonrc xpbsmonrc.src
        sed -e "s/localhost.localdomain/$HNAME/" xpbsmonrc.src > xpbsmonrc
	rm -rf xpbsmonrc.src
else
        echo "WARNING: /usr/local/%{name}-%{version}-%{release}/lib/xpbs/xpbmonsrc does not exist."
fi

# Build tcl indices for xpbsmon and xpbs.  It uses absolute path names
# so it won't work with a different buildroot.
XPBSMON_LIB=/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon
cd ${XPBSMON_LIB} && ./buildindex ${XPBSMON_LIB} && chmod 644 tclIndex
XPBS_LIB=/usr/local/%{name}-%{version}-%{release}/lib/xpbs
cd ${XPBS_LIB} && ./buildindex ${XPBS_LIB} && chmod 644 tclIndex



#####################
##  PRE-UNINSTALL  ##
#####################

%preun server
if [ "$1" = 0 ]; then
	/sbin/service pbs_server stop > /dev/null 2>&1
	/sbin/chkconfig --del pbs_server
fi

%preun mom
if [ "$1" = 0 ]; then
	/sbin/service pbs_mom stop > /dev/null 2>&1
	/sbin/chkconfig --del pbs_mom
fi

%preun sched
if [ "$1" = 0 ]; then
	/sbin/service pbs_sched stop > /dev/null 2>&1
	/sbin/chkconfig --del pbs_sched
fi




######################
##  POST-UNINSTALL  ##
######################

%postun core

# Remove empty directory
rm -rf /usr/local/%{name}-%{version}-%{release}

# Restore back-up if it exists
if [ -e /usr/local/%{name}-%{version}-%{release}.rpmsave ]; then
	mv /usr/local/%{name}-%{version}-%{release}.rpmsave /usr/local/%{name}-%{version}-%{release}
fi

if [ $1 = 0 ]; then
	rm -f /usr/local/%{name}
	if [ -e /usr/local/%{name}.rpmsave ]; then
		mv /usr/local/%{name}.rpmsave /usr/local/%{name}
	fi
	rm -f /usr/share/modulefiles/%{name}
	rm -f /usr/local/share/modulefiles/%{name}
fi

# NOTE: We do not restart mom's automatically because we do not want to
# risk losing jobs.


##############
##  VERIFY  ##
##############

# UGLY HACK WARNING !!!!
# These verification scripts are used to restore config files that were
# saved during an upgrade since rpm does not properly handle links to
# config files.

%verifyscript core
for f in /var/spool/pbs/pbs_environment; do
	if [ -L "$f.rpmsave" ]; then
		mv -f $f $f.rpmnew
		mv -f $f.rpmsave $f
	fi
done


%verifyscript server
for f in /var/spool/pbs/server_name; do
        if [ -L "$f.rpmsave" ]; then
                mv -f $f $f.rpmnew
                mv -f $f.rpmsave $f
        fi
done
echo "Restarting PBS server..."
/sbin/service pbs_server condrestart


%verifyscript sched
for f in /var/spool/pbs/sched_priv/sched_config \
         /var/spool/pbs/sched_priv/resource_group \
         /var/spool/pbs/sched_priv/holidays \
         /var/spool/pbs/sched_priv/dedicated_time; do
        if [ -L "$f.rpmsave" ]; then
                mv -f $f $f.rpmnew
                mv -f $f.rpmsave $f
        fi
done
echo "Restarting PBS scheduler..."
/sbin/service pbs_sched condrestart




#############
##  CLEAN  ##
#############

%clean
rm -rf $RPM_BUILD_ROOT


#############
##  FILES  ##
#############

%files core
%defattr(-,root,root)
%dir /var/spool/pbs
%dir /var/spool/pbs/aux
%attr(1777,root,root) %dir /var/spool/pbs/spool
%attr(1777,root,root) %dir /var/spool/pbs/undelivered
%attr(700,root,root) %dir /var/spool/pbs/checkpoint
%config /var/spool/pbs/pbs_environment
%config /usr/share/modulefiles/%{name}-%{version}-%{release}
%config /usr/local/share/modulefiles/%{name}-%{version}-%{release}
/usr/local/%{name}-%{version}-%{release}/bin/pbs_wish
/usr/local/%{name}-%{version}-%{release}/sbin/pbs_iff
/usr/local/%{name}-%{version}-%{release}/lib/pbs_sched.a
/usr/local/%{name}-%{version}-%{release}/lib/libattr.a
/usr/local/%{name}-%{version}-%{release}/lib/libcmds.a
/usr/local/%{name}-%{version}-%{release}/lib/liblog.a
/usr/local/%{name}-%{version}-%{release}/lib/libnet.a
/usr/local/%{name}-%{version}-%{release}/lib/libpbs.a
/usr/local/%{name}-%{version}-%{release}/lib/libsite.a
/usr/local/%{name}-%{version}-%{release}/include/pbs_error.h
/usr/local/%{name}-%{version}-%{release}/include/pbs_ifl.h
/usr/local/%{name}-%{version}-%{release}/include/tm.h
/usr/local/%{name}-%{version}-%{release}/include/tm_.h
%doc /usr/share/doc/%{name}-%{version}-%{release}/PBS_License.txt
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/pbs.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_alterjob.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_connect.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_deljob.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_default.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_disconnect.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_geterrmsg.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_holdjob.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_manager.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_movejob.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_msgjob.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_orderjob.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_rescreserve.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_rescquery.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_rerunjob.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_rlsjob.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_runjob.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_selectjob.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_sigjob.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_stagein.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_statjob.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_statque.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_statserver.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_submit.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/pbs_terminate.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/rpp.3B
%doc /usr/local/%{name}-%{version}-%{release}/man/man3/tm.3B


%files server
%defattr(-,root,root)
/usr/local/%{name}-%{version}-%{release}/sbin/pbs_server
/usr/local/%{name}-%{version}-%{release}/bin/qterm
%attr(750,root,root) %dir /var/spool/pbs/server_priv
%dir /var/spool/pbs/server_priv/jobs
%dir /var/spool/pbs/server_priv/queues
%dir /var/spool/pbs/server_priv/acl_svr
%dir /var/spool/pbs/server_priv/acl_hosts
%dir /var/spool/pbs/server_priv/acl_users
%dir /var/spool/pbs/server_priv/acl_groups
%dir /var/spool/pbs/server_priv/accounting
%dir /var/spool/pbs/server_logs
%config /var/spool/pbs/server_name
%doc /usr/local/%{name}-%{version}-%{release}/man/man8/pbs_server.8B
%doc /usr/local/%{name}-%{version}-%{release}/man/man8/qterm.8B
%config /etc/rc.d/init.d/pbs_server
%config /etc/pam.d/pbs-server


%files sched
%defattr(-,root,root)
/usr/local/%{name}-%{version}-%{release}/sbin/pbs_sched
%dir /var/spool/pbs/sched_logs
%attr(750,root,root) %dir /var/spool/pbs/sched_priv
%config /var/spool/pbs/sched_priv/sched_config
%config /var/spool/pbs/sched_priv/resource_group
%config /var/spool/pbs/sched_priv/holidays
%config /var/spool/pbs/sched_priv/dedicated_time
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/basl2c.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man8/pbs_sched_cc.8B
%doc /usr/local/%{name}-%{version}-%{release}/man/man8/pbs_sched_basl.8B
%doc /usr/local/%{name}-%{version}-%{release}/man/man8/pbs_sched_tcl.8B
%config /etc/rc.d/init.d/pbs_sched


%files mom
%defattr(-,root,root)
/usr/local/%{name}-%{version}-%{release}/sbin/pbs_mom
/usr/local/%{name}-%{version}-%{release}/sbin/pbs_rcp
/usr/local/%{name}-%{version}-%{release}/sbin/pbs_demux
/usr/local/%{name}-%{version}-%{release}/bin/pbsdsh
%dir /var/spool/pbs/mom_logs
%attr(751,root,root) %dir /var/spool/pbs/mom_priv
%dir /var/spool/pbs/mom_priv/jobs
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/pbsdsh.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man8/pbs_mom.8B
%config /etc/rc.d/init.d/pbs_mom


%files commands
%defattr(-,root,root)
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/bitmaps/cyclist-only.xbm
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/bitmaps/hourglass.bmp
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/bitmaps/iconize.bmp
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/bitmaps/logo.bmp
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/bitmaps/maximize.bmp
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/help/auto_update.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/help/main.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/help/notes.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/help/pref.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/help/prefQuery.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/help/prefServer.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/preferences.tcl
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/auto_upd.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/bindings.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/box.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/button.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/cluster.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/color.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/common.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/dialog.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/entry.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/expr.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/listbox.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/main.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/node.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/pbs.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/prefsave.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/pref.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/spinbox.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/system.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/wmgr.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/buildindex
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/tclIndex
/usr/local/%{name}-%{version}-%{release}/lib/xpbsmon/xpbsmonrc
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/bitmaps/curve_down_arrow.bmp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/bitmaps/curve_up_arrow.bmp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/bitmaps/cyclist-only.xbm
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/bitmaps/Downarrow.bmp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/bitmaps/hourglass.bmp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/bitmaps/iconize.bmp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/bitmaps/logo.bmp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/bitmaps/maximize.bmp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/bitmaps/sm_down_arrow.bmp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/bitmaps/sm_up_arrow.bmp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/bitmaps/Uparrow.bmp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/after_depend.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/auto_update.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/before_depend.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/concur.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/datetime.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/delete.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/email.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/fileselect.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/hold.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/main.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/message.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/misc.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/modify.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/move.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/notes.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/preferences.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/release.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/select.acctname.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/select.checkpoint.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/select.hold.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/select.jobname.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/select.owners.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/select.priority.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/select.qtime.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/select.rerun.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/select.resources.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/select.states.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/signal.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/staging.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/submit.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/terminate.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/help/trackjob.hlp
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/bin/xpbs_datadump
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/bin/xpbs_scriptload
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/pbs.tcl
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/preferences.tcl
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/acctname.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/after_depend.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/auto_upd.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/before_depend.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/bindings.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/box.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/button.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/checkpoint.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/common.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/concur.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/datetime.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/email_list.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/entry.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/fileselect.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/hold.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/jobname.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/listbox.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/main.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/misc.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/owners.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/prefsave.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/pref.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/priority.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/qalter.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/qdel.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/qhold.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/qmove.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/qmsg.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/qrls.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/qsig.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/qsub.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/qterm.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/qtime.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/rerun.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/res.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/spinbox.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/staging.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/state.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/text.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/trackjob.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/wmgr.tk
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/buildindex
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/tclIndex
/usr/local/%{name}-%{version}-%{release}/lib/xpbs/xpbsrc
/usr/local/%{name}-%{version}-%{release}/bin/xpbsmon
/usr/local/%{name}-%{version}-%{release}/bin/qalter
/usr/local/%{name}-%{version}-%{release}/bin/qdel
/usr/local/%{name}-%{version}-%{release}/bin/qhold
/usr/local/%{name}-%{version}-%{release}/bin/qmove
/usr/local/%{name}-%{version}-%{release}/bin/qorder
/usr/local/%{name}-%{version}-%{release}/bin/qmsg
/usr/local/%{name}-%{version}-%{release}/bin/qrerun
/usr/local/%{name}-%{version}-%{release}/bin/qrls
/usr/local/%{name}-%{version}-%{release}/bin/qselect
/usr/local/%{name}-%{version}-%{release}/bin/qsig
/usr/local/%{name}-%{version}-%{release}/bin/qstat
/usr/local/%{name}-%{version}-%{release}/bin/qsub
/usr/local/%{name}-%{version}-%{release}/bin/qdisable
/usr/local/%{name}-%{version}-%{release}/bin/qenable
/usr/local/%{name}-%{version}-%{release}/bin/qrun
/usr/local/%{name}-%{version}-%{release}/bin/qstart
/usr/local/%{name}-%{version}-%{release}/bin/qstop
/usr/local/%{name}-%{version}-%{release}/bin/pbsnodes
/usr/local/%{name}-%{version}-%{release}/bin/qmgr
/usr/local/%{name}-%{version}-%{release}/bin/nqs2pbs
/usr/local/%{name}-%{version}-%{release}/bin/pbs_tclsh
/usr/local/%{name}-%{version}-%{release}/bin/xpbs
/usr/local/%{name}-%{version}-%{release}/bin/tracejob
/usr/local/%{name}-%{version}-%{release}/bin/hostn
/usr/local/%{name}-%{version}-%{release}/bin/printjob
/usr/local/%{name}-%{version}-%{release}/bin/chk_tree
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/qalter.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/qdel.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/qhold.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/qmove.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/qmsg.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/qorder.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/qrerun.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/qrls.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/qselect.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/qsig.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/qstat.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/qsub.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/xpbs.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/xpbsmon.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man1/nqs2pbs.1B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_job_attributes.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_queue_attributes.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_server_attributes.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_resources_all.soB
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_resources_aix4.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_resources_digitalunix.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_resources_freebsd.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_resources_fujitsu.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_resources_irix5.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_resources_irix6array.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_resources_irix6.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_resources_linux.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_resources_netbsd.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_resources_solaris5.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_resources_solaris7.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_resources_sp2.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_resources_sunos4.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_resources_unicos8.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_resources_unicosmk2.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man7/pbs_resources.7B
%doc /usr/local/%{name}-%{version}-%{release}/man/man8/qdisable.8B
%doc /usr/local/%{name}-%{version}-%{release}/man/man8/qenable.8B
%doc /usr/local/%{name}-%{version}-%{release}/man/man8/qmgr.8B
%doc /usr/local/%{name}-%{version}-%{release}/man/man8/qrun.8B
%doc /usr/local/%{name}-%{version}-%{release}/man/man8/qstart.8B
%doc /usr/local/%{name}-%{version}-%{release}/man/man8/qstop.8B
%doc /usr/local/%{name}-%{version}-%{release}/man/man8/pbsnodes.8B


#################
##  CHANGELOG  ##
#################

%changelog
* Fri Aug  6 2004 Pete Wyckoff <pw@osc.edu>
- Redo meminfo patch to handle linux-2.6 kernels as well as 2.4.

* Mon Aug  2 2004 Rick Mohr <rfmohr@osc.edu>
- Added default /etc/pam.d/pbs-server file to rpm package.

* Sun Aug  1 2004 Pete Wyckoff <pw@osc.edu>
- reduce TCP timeout
- reduce ping_nodes frequency

* Wed Jul 21 2004 Rick Mohr <rfmohr@osc.edu>
- Added pam_ruserok patch: This allows the pbs server to authenticate
  job submission requests via PAM instead of just using ruserok().

* Mon Jul 19 2004 Rick Mohr <rfmohr@osc.edu>
- Fixed gcc32 patch so that sed expressions were valid.

* Fri Jul 16 2004 Pete Wyckoff <pw@osc.edu>
- add interactive-with-patch from Michel Kouril.

* Sat Apr 17 2004 Pete Wyckoff <pw@osc.edu>
- redo patch set using AKPM patch-scripts, include more-server-sockets.

* Thu Mar 11 2004 Pete Wyckoff <pw@osc.edu>
- add vmem-accounting patch: fix vmem to mean rss, get rid of stack limit,
  account thread/shared mem correctly

* Mon Aug 25 2003 Rick Mohr <rfmohr@osc.edu>
- Added patches to get PBS to compile under RedHat 9
- Updated previous patches from Pete
- Spec file creates modulefile for modules package now
- Modified init scripts to support condrestart option and
  create PID file.
- Added verify script to restore .rpmsave config files and
  restart server and scheduler.

* Tue Oct  1 2002 Rick Mohr <rfmohr@osc.edu>
- Changed pbs_mom init script to use default config file.
- Edited spec file to use %%{name} instead of "pbs" in many places.

* Wed Sep 11 2002 Rick Mohr <rfmohr@osc.edu>
- Added modulefile to rpm for use with Modules package

* Fri Aug 30 2002 Rick Mohr <rfmohr@osc.edu>
- Added many of Pete's patches (described below)

* Tue Aug 27 2002 Pete Wyckoff <pw@osc.edu>
- add Wendy lin prologue-bounce patch
- add four interesting patches from Ben
- reorder patches to apply stock mpiexec first

* Tue Aug 13 2002 Rick Mohr <rfmohr@osc.edu>
- Split package into 5 sub-packages
- Fixed references to rebuild root that were hardcoded into files
- Created pre/post install/uninstall scripts

* Wed Jun 12 2002 Pete Wyckoff <pw@osc.edu>
- fix file descriptor leak as described by Wendy Lin 20 Mar 02

* Mon Jun 10 2002 Pete Wyckoff <pw@osc.edu>
- increase PBS_PROLOG_TIME to 2 minutes to avoid -4 prolog exits

* Fri May 24 2002 Pete Wyckoff <pw@osc.edu>
- increase arbitrary constant string limits in
- src/server/node_manager.c src/include/acct.h.

* Wed Apr  3 2002 Doug Johnson <djohnson@osc.edu>
- Initial build.
- Need to add explicit permissions on file list above.
- Need to distinguish between file, scripts, docs.
- Need to install documentation.
- rpm.diff should include OSC readme, startup scripts.
- Should explicitly disable --prefix option for RPM.

* Wed Mar 27 2002 Pete Wyckoff <pw@osc.edu>
- Changes in src/resmom/linux/mom_mach.c to try to detect mom self-killing.
- Installed on ia64, but did not restart moms.

* Wed Jan  2 2002 Pete Wyckoff <pw@osc.edu>
- Pass PBS_RESOURCE_NODES in env to pro/epilogue scripts.

* Tue Dec  4 2001 Pete Wyckoff <pw@osc.edu>
- Change mpiexec patch

* Tue Oct 23 2001 Pete Wyckoff <pw@osc.edu>
- Change RPP_RETRY to 30, first recompile with rh7.2 system.

* Sun Aug 26 2001 Pete Wyckoff <pw@osc.edu>
- Increase linesize in tracejob else it chops off entries.

* Thu Aug  9 2001 Pete Wyckoff <pw@osc.edu>
- Make the read call in svr_disconnect be blocking to avoid endlessly
- looping confused server bug #23.

* Tue Aug  7 2001 Pete Wyckoff <pw@osc.edu>
- increased pbs_tcp_timeout from 30 to 60 in three places in two files
- don't overwrite server_name file on every install

* Fri Aug  3 2001 Pete Wyckoff <pw@osc.edu>
- ia64 changes: pull config.{sub,guess} from a more modern distro (lam)

* Thu Mar 15 2001 Pete Wyckoff <pw@osc.edu>
- fixed addr_ok()

* Thu Mar 15 2001 Pete Wyckoff <pw@osc.edu>
- rebuilt and installed with cplant patches

